unsupported_direct_put_reason

Function unsupported_direct_put_reason 

fn unsupported_direct_put_reason(key: &str) -> Option<String>
Returns the rejection reason for keys that should not be updated by put key.

These keys may be decodable, but they are not safe to update via raw KV writes. __table_route/* is the canonical example.