fn unsupported_direct_put_reason(key: &str) -> Option<String>Expand description
Returns the rejection reason for keys that should not be updated by put key.
These keys may be decodable, but they are not safe to update via raw KV writes.
__table_route/* is the canonical example.